summaryrefslogtreecommitdiff
path: root/apps
diff options
context:
space:
mode:
authorTor Andersson <tor.andersson@artifex.com>2012-10-02 16:52:45 +0200
committerRobin Watts <robin.watts@artifex.com>2012-10-05 15:54:56 +0100
commitae5749c4139982079bd35698a3c3c23e4ec9147e (patch)
tree6c03bc26152ee69122d8a1535283a180d5db3b52 /apps
parent8aa48c0f5766a0d62489cb42225cd03f3d1a2a62 (diff)
downloadmupdf-ae5749c4139982079bd35698a3c3c23e4ec9147e.tar.xz
Rename mubusy to mutool.
Diffstat (limited to 'apps')
-rw-r--r--apps/man/mutool.1 (renamed from apps/man/mubusy.1)12
-rw-r--r--apps/mutool.c (renamed from apps/mubusy.c)4
-rw-r--r--apps/pdfclean.c (renamed from apps/mupdfclean.c)2
-rw-r--r--apps/pdfextract.c (renamed from apps/mupdfextract.c)2
-rw-r--r--apps/pdfinfo.c (renamed from apps/mupdfinfo.c)2
-rw-r--r--apps/pdfposter.c (renamed from apps/mupdfposter.c)2
-rw-r--r--apps/pdfshow.c (renamed from apps/mupdfshow.c)2
7 files changed, 13 insertions, 13 deletions
diff --git a/apps/man/mubusy.1 b/apps/man/mutool.1
index 435dba4d..a2b7d42c 100644
--- a/apps/man/mubusy.1
+++ b/apps/man/mutool.1
@@ -1,18 +1,18 @@
-.TH "MUBUSY" "1" "May 10, 2012"
+.TH "MUTOOL" "1" "Oct 02, 2012"
.\" Please adjust this date whenever revising the manpage.
.\" no hyphenation
.nh
.\" adjust left
.ad l
.SH NAME
-mubusy \- all purpose tool for dealing with PDF files
+mutool \- all purpose tool for dealing with PDF files
.SH SYNOPSIS
-mubusy <sub-command> [options]
+mutool <sub-command> [options]
.SH DESCRIPTION
-mubusy is a tool based on MuPDF for dealing with PDF files in various manners.
+mutool is a tool based on MuPDF for dealing with PDF files in various manners.
There are several sub commands available, as described below.
.SH CLEAN
-mubusy clean [options] input.pdf [output.pdf] [pages]
+mutool clean [options] input.pdf [output.pdf] [pages]
.PP
The clean command pretty prints and rewrites the syntax of a PDF file.
It can be used to repair broken files, expand compressed streams, filter
@@ -42,7 +42,7 @@ TODO
.SH POSTER
TODO
.SH SHOW
-mubusy show [options] file.pdf [object numbers ...]
+mutool show [options] file.pdf [object numbers ...]
.PP
The show command will print the specified objects and streams to stdout.
Streams are decoded and non-printable characters are represented
diff --git a/apps/mupdfclean.c b/apps/pdfclean.c
index fdf9b412..409d4fbb 100644
--- a/apps/mupdfclean.c
+++ b/apps/pdfclean.c
@@ -18,7 +18,7 @@ static fz_context *ctx = NULL;
static void usage(void)
{
fprintf(stderr,
- "usage: mubusy clean [options] input.pdf [output.pdf] [pages]\n"
+ "usage: mutool clean [options] input.pdf [output.pdf] [pages]\n"
"\t-p -\tpassword\n"
"\t-g\tgarbage collect unused objects\n"
"\t-gg\tin addition to -g compact xref table\n"
diff --git a/apps/mupdfextract.c b/apps/pdfextract.c
index 95f27be9..7d49f997 100644
--- a/apps/mupdfextract.c
+++ b/apps/pdfextract.c
@@ -11,7 +11,7 @@ static int dorgb = 0;
static void usage(void)
{
- fprintf(stderr, "usage: mubusy extract [options] file.pdf [object numbers]\n");
+ fprintf(stderr, "usage: mutool extract [options] file.pdf [object numbers]\n");
fprintf(stderr, "\t-p\tpassword\n");
fprintf(stderr, "\t-r\tconvert images to rgb\n");
exit(1);
diff --git a/apps/mupdfinfo.c b/apps/pdfinfo.c
index 6c0a31d7..3fab99c7 100644
--- a/apps/mupdfinfo.c
+++ b/apps/pdfinfo.c
@@ -154,7 +154,7 @@ static void
infousage(void)
{
fprintf(stderr,
- "usage: mubusy info [options] [file.pdf ... ]\n"
+ "usage: mutool info [options] [file.pdf ... ]\n"
"\t-d -\tpassword for decryption\n"
"\t-f\tlist fonts\n"
"\t-i\tlist images\n"
diff --git a/apps/mupdfposter.c b/apps/pdfposter.c
index f65495a8..2ef44dbb 100644
--- a/apps/mupdfposter.c
+++ b/apps/pdfposter.c
@@ -18,7 +18,7 @@ static int y_factor = 0;
static void usage(void)
{
fprintf(stderr,
- "usage: mubusy poster [options] input.pdf [output.pdf]\n"
+ "usage: mutool poster [options] input.pdf [output.pdf]\n"
"\t-p -\tpassword\n"
"\t-x\tx decimation factor\n"
"\t-y\ty decimation factor\n");
diff --git a/apps/mupdfshow.c b/apps/pdfshow.c
index f534a5c7..655493f9 100644
--- a/apps/mupdfshow.c
+++ b/apps/pdfshow.c
@@ -12,7 +12,7 @@ static int showcolumn;
static void usage(void)
{
- fprintf(stderr, "usage: mubusy show [options] file.pdf [grepable] [xref] [trailer] [pagetree] [object numbers]\n");
+ fprintf(stderr, "usage: mutool show [options] file.pdf [grepable] [xref] [trailer] [pagetree] [object numbers]\n");
fprintf(stderr, "\t-b\tprint streams as binary data\n");
fprintf(stderr, "\t-e\tprint encoded streams (don't decode)\n");
fprintf(stderr, "\t-p\tpassword\n");
diff --git a/apps/mubusy.c b/apps/mutool.c
index e11d488c..2eb0d7c5 100644
--- a/apps/mubusy.c
+++ b/apps/mutool.c
@@ -1,5 +1,5 @@
/*
* mubusy -- swiss army knife of pdf manipulation tools
*/
#include <stdio.h>
@@ -74,7 +74,7 @@ int main(int argc, char **argv)
/* Print usage */
- fprintf(stderr, "usage: mubusy <command> [options]\n");
+ fprintf(stderr, "usage: mutool <command> [options]\n");
for (i = 0; i < nelem(tools); i++)
fprintf(stderr, "\t%s\t-- %s\n", tools[i].name, tools[i].desc);
@@ -1,5 +1,5 @@
/*
- * mubusy -- swiss army knife of pdf manipulation tools
+ * mutool -- swiss army knife of pdf manipulation tools
*/
#include <stdio.h>